Module traits
struct_
threads
1.0.1
Module traits
Module Items
Traits
In crate struct_
threads
struct_threads
Module
traits
Traits

Runnable
A trait for defining a task that can be executed, typically in a separate thread.
Thread
An extension trait that provides a method to spawn a thread for a
Runnable
task.