Module traits

Module traits 

Traits

AsyncRunnable
A trait for defining an async task that can be executed, typically in a Tokio runtime.
ParallelRun
An extension trait that provides a method to run multiple Runnable’s in parallel.
Runnable
A trait for defining a task that can be executed, typically in a separate thread.
Thread
An extension trait that provides a method to spawn a thread for a Runnable task.
TokioParallelRuntokio
An extension trait that provides a method to run multiple AsyncRunnable’s in parallel using Tokio.
TokioTasktokio
An extension trait that provides a method to spawn a Tokio task for an AsyncRunnable task.