Traits
- Async
Runnable - A trait for defining an async task that can be executed, typically in a Tokio runtime.
- Parallel
Run - An extension trait that provides a method to run multiple
Runnable’s in parallel. - Runnable
- A trait for defining a task that can be executed, typically in a separate thread.
- Thread
- An extension trait that provides a method to spawn a thread for a
Runnabletask.